use std::os::raw::c_char;
use std::ffi::CString;

extern "C" {
  fn open_connect(nom:*const c_char) -> u32;
}

pub fn rust_connect(nom:&str)-> u32{
  let nom1=CString::new(nom).unwrap();
  let c_ptr: *const c_char = nom1.as_ptr();
  let res = unsafe{open_connect(c_ptr)};
  res
}
